#!/bin/csh -f

# The ce directory must be in JLAB_ROOT

# Override any of these with an environment variable
# w/o the "DEFAULT_" prefix. 
# For example, to override DEFAULT_ROOT_VERSION
# set the environment variable ROOT_VERSION

set DEFAULT_JLAB_ROOT      = /site/12gev_phys

# Software version defaults
set DEFAULT_CLHEP_VERSION  = 2.1.0.1 
set DEFAULT_GEANT4_VERSION = 4.9.3.p02
set DEFAULT_JANA_VERSION   = 0.6.2
set DEFAULT_MYSQL_LOCATION = mysql     # Users can set the MYSQINC and MYSQLIB too.
set DEFAULT_QT_VERSION     = 4.7.1
set DEFAULT_ROOT_VERSION   = 5.28

# Add software in th package list
set packages = (clhep geant4 mysql qt root xerces jlab12)

# Only print out if there's a prompt
alias echo 'if($?prompt) echo \!*  '


# Do not edit below this line
#############################
echo

# Looking for user defined JLAB_ROOT
if($?JLAB_ROOT) then
	if($JLAB_ROOT != $DEFAULT_JLAB_ROOT) then
		echo " >> User Defined JLAB_ROOT env variable set to:"  $JLAB_ROOT
	endif
else
		setenv JLAB_ROOT $DEFAULT_JLAB_ROOT
endif


# Looking for custom defined OSRELEASE
set DEFAULT_OSRELEASE = `$JLAB_ROOT/ce/osrelease.pl`
if($?OSRELEASE) then
	if($OSRELEASE != $DEFAULT_OSRELEASE) then
		echo " >> User defined OSRELEASE set to:"  $OSRELEASE
	endif
	else
	setenv OSRELEASE $DEFAULT_OSRELEASE
endif

# JLAB_SOFTWARE is where all the architecture software will be
setenv JLAB_SOFTWARE $JLAB_ROOT/$OSRELEASE

echo
echo " > Common Environment" 
echo " > Running as "`whoami` on `hostname`
echo " > OSRelease: "$OSRELEASE
echo

if( -d $JLAB_SOFTWARE) then
	echo
	echo " > JLAB_SOFTWARE set to:  " $JLAB_SOFTWARE
else
	echo " Error. " $JLAB_SOFTWARE is not a directory. Exiting.
	exit
endif


# Sourcing packages. This will set the LD_LIBRARY_PATH. 
# Powerpcs and Darwins will be set right below
if( ! $?LD_LIBRARY_PATH) then
	setenv LD_LIBRARY_PATH ""
endif
if( ! $?PYTHONPATH) then
	setenv PYTHONPATH "."
endif

foreach p ($packages)
	source $JLAB_ROOT/ce/$p".env"
end


# for powerpcs: LIBPATH
if ( $?LIBPATH ) then
  setenv LIBPATH ${LD_LIBRARY_PATH}:${LIBPATH}
else
  setenv LIBPATH ${LD_LIBRARY_PATH}
endif
# for Darwins systems: DYLD_LIBRARY_PATH
if ( $?DYLD_LIBRARY_PATH ) then
  setenv DYLD_LIBRARY_PATH ${LD_LIBRARY_PATH}:${DYLD_LIBRARY_PATH}
else
  setenv DYLD_LIBRARY_PATH ${LD_LIBRARY_PATH}
endif

echo



